@@ -1,9 +1,8 @@
 ;;; gnorb-org.el --- The Org-centric functions of gnorb -*- lexical-binding: t -*-
 
-;; Copyright (C) 2018  Free Software Foundation, Inc.
+;; Copyright (C) 2018-2020  Free Software Foundation, Inc.
 
 ;; Author: Eric Abrahamsen  <eric@ericabrahamsen.net>
-;; Keywords:
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -780,10 +779,10 @@ search."
 	     (let ((bound (org-element-property
 			   :end (org-element-at-point)))
 		   desc rec)
-	       (while (re-search-forward
-		       org-bracket-link-analytic-regexp bound t)
-		 (when (string-match-p "bbdb" (match-string 2))
-		   (setq desc (match-string 5)
+	       (while (re-search-forward org-link-any-re bound t)
+		 (when (string-match-p "bbdb" (car (split-string
+						    (match-string 2) ":")))
+		   (setq desc (match-string 3)
 			 rec (bbdb-search (bbdb-records) desc desc desc)
 			 recs (append recs rec))))))))
     (if recs
